==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/TreemapNodePointerEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TreemapNodePointerEventArgsDescription } from "./TreemapNodePointerEventArgsDescription";
/**
 * @hidden
 */
var TreemapNodePointerEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TreemapNodePointerEventArgsDescriptionMetadata, _super);
    function TreemapNodePointerEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TreemapNodePointerEventArgsDescriptionMetadata.b = function (a) {
        if (TreemapNodePointerEventArgsDescriptionMetadata.a == null) {
            TreemapNodePointerEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TreemapNodePointerEventArgsDescriptionMetadata.c(TreemapNodePointerEventArgsDescriptionMetadata.a);
        }
        if (a.g(TreemapNodePointerEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(TreemapNodePointerEventArgsDescriptionMetadata.a);
    };
    TreemapNodePointerEventArgsDescriptionMetadata.c = function (a) {
        a.item("Value", "Number:double");
        a.item("Sum", "Number:double");
        a.item("CustomValueRef", "(w:CustomValue,wf:CustomValue)DataRef");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("ParentItemRef", "(w:ParentItem,wf:ParentItem)DataRef");
        a.item("Position", "Point");
        a.item("IsRightButton", "Boolean");
        a.item("IsHandled", "Boolean");
        a.item("IsOverHeader", "Boolean");
        a.item("Label", "String");
        a.item("ParentValue", "Number:double");
        a.item("ParentLabel", "String");
        a.item("ParentSum", "Number:double");
    };
    TreemapNodePointerEventArgsDescriptionMetadata.d = function (a) {
        TreemapNodePointerEventArgsDescriptionMetadata.b(a);
        a.u("TreemapNodePointerEventArgs", function () { return new TreemapNodePointerEventArgsDescription(); });
        a.t("TreemapNodePointerEventArgs", TreemapNodePointerEventArgsDescriptionMetadata.a);
    };
    TreemapNodePointerEventArgsDescriptionMetadata.$t = markType(TreemapNodePointerEventArgsDescriptionMetadata, 'TreemapNodePointerEventArgsDescriptionMetadata');
    TreemapNodePointerEventArgsDescriptionMetadata.a = null;
    return TreemapNodePointerEventArgsDescriptionMetadata;
}(Base));
export { TreemapNodePointerEventArgsDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/TreemapNodePointerEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { TreemapNodePointerEventArgsDescription } from "./TreemapNodePointerEventArgsDescription";
/**
 * @hidden
 */
var TreemapNodePointerEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(TreemapNodePointerEventArgsDescriptionMetadata, _super);
    function TreemapNodePointerEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    TreemapNodePointerEventArgsDescriptionMetadata.b = function (a) {
        if (TreemapNodePointerEventArgsDescriptionMetadata.a == null) {
            TreemapNodePointerEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            TreemapNodePointerEventArgsDescriptionMetadata.c(TreemapNodePointerEventArgsDescriptionMetadata.a);
        }
        if (a.j(TreemapNodePointerEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(TreemapNodePointerEventArgsDescriptionMetadata.a);
    };
    TreemapNodePointerEventArgsDescriptionMetadata.c = function (a) {
        a.item("Value", "Number:double");
        a.item("Sum", "Number:double");
        a.item("CustomValueRef", "(w:CustomValue,wf:CustomValue)DataRef");
        a.item("ItemRef", "(w:Item,wf:Item)DataRef");
        a.item("ParentItemRef", "(w:ParentItem,wf:ParentItem)DataRef");
        a.item("Position", "Point");
        a.item("IsRightButton", "Boolean");
        a.item("IsHandled", "Boolean");
        a.item("IsOverHeader", "Boolean");
        a.item("Label", "String");
        a.item("ParentValue", "Number:double");
        a.item("ParentLabel", "String");
        a.item("ParentSum", "Number:double");
    };
    TreemapNodePointerEventArgsDescriptionMetadata.d = function (a) {
        TreemapNodePointerEventArgsDescriptionMetadata.b(a);
        a.aa("TreemapNodePointerEventArgs", function () { return new TreemapNodePointerEventArgsDescription(); });
        a.z("TreemapNodePointerEventArgs", TreemapNodePointerEventArgsDescriptionMetadata.a);
    };
    TreemapNodePointerEventArgsDescriptionMetadata.$t = markType(TreemapNodePointerEventArgsDescriptionMetadata, 'TreemapNodePointerEventArgsDescriptionMetadata');
    TreemapNodePointerEventArgsDescriptionMetadata.a = null;
    return TreemapNodePointerEventArgsDescriptionMetadata;
}(Base));
export { TreemapNodePointerEventArgsDescriptionMetadata };
